SuspenderSuspendRequest

Struct SuspenderSuspendRequest 

pub struct SuspenderSuspendRequest {
    pub state_index: Option<u64>,
    /* private fields */
}

Fields

state_index: Option<u64>

This index corresponds to an entry in the vector returned by GetSuspendStates. Returns ZX_ERR_OUT_OF_RANGE if state_index is greater than the number of supported suspend states. Returns ZX_ERR_INVALID_ARGS if this field is unset.